#ifndef _OTH_DATALIB_H_
#define _OTH_DATALIB_H_
extern void oth_init(void);
extern void oth_section_size(int);
extern void oth_material_size(int);
extern void oth_geometry_size(int);
extern void oth_feed_size(int);
extern void oth_load_size(int);
extern void oth_point_size(int);
extern void oth_far1d_size(int);
extern void oth_near1d_size(int);
extern void oth_near2d_size(int);
extern void oth_title(const char []);
extern void oth_xsection1(double);
extern void oth_ysection1(double);
extern void oth_zsection1(double);
extern void oth_xdivision1(int);
extern void oth_ydivision1(int);
extern void oth_zdivision1(int);
extern void oth_xsection(int, ...);
extern void oth_ysection(int, ...);
extern void oth_zsection(int, ...);
extern void oth_xdivision(int, ...);
extern void oth_ydivision(int, ...);
extern void oth_zdivision(int, ...);
extern void oth_material(double, double, double, double);
extern void oth_material_dispersion(const char []);
extern void oth_geometry(int, int, double, double, double, double, double, double);
extern void oth_geometry_array(int, int, const double []);
extern void oth_geometry_name(const char name[]);
extern void oth_feed(char, double, double, double, double, double, double);
extern void oth_planewave(double, double, int);
extern void oth_planewave_ellipse(double, double, double, double);
extern void oth_semispace(char, double);
extern void oth_fullspace(void);
extern void oth_load(char, double, double, double, char, double);
extern void oth_point(char, double, double, double, const char []);
extern void oth_frequency(double, double, int);
extern void oth_solver(int, int, double);
extern void oth_pml(int, double, double);
extern void oth_pbc(int, int, int);
extern void ofd_matchingloss(void);
extern void oth_plotiter(int, int);
extern void oth_plotsmith(void);
extern void oth_plotzin(int, double, double, int);
extern void oth_plotyin(int, double, double, int);
extern void oth_plotref(int, double, double, int);
extern void oth_plotspara(int, double, double, int);
extern void oth_plotloss(int, double, double, int);
extern void oth_plotcoupling(int, double, double, int);
extern void oth_plotfar0d(double, double, int, double, double, int);
extern void oth_freqdiv(int);
extern void oth_plotfar1d(char, int, double);
extern void oth_far1dcomponent(int, int, int);
extern void oth_far1dstyle(int);
extern void oth_far1ddb(int);
extern void ofd_far1dnorm(void);
extern void oth_far1dscale(double, double, int);
extern void oth_plotfar2d(int, int);
extern void oth_far2dcomponent(int, int, int, int, int, int, int);
extern void oth_far2ddb(int);
extern void oth_far2dscale(double, double);
extern void oth_far2dobj(double);
extern void oth_plotnear1d(const char [], char, double, double);
extern void oth_near1ddb(int);
extern void oth_near1dscale(double, double, int);
extern void oth_near1dexclude(int);
extern void oth_plotnear2d(const char [], char, double);
extern void oth_near2ddim(int, int);
extern void oth_near2dframe(int);
extern void oth_near2ddb(int);
extern void oth_near2dscale(double, double);
extern void oth_near2dcontour(int);
extern void oth_near2dobj(int);
extern void oth_near2dexclude(int);
extern void oth_near2dzoom(double, double, double, double);
extern void oth_outdata(const char []);
#endif  // _OTH_DATALIB_H_
